// Copyright (c) 2013 by István Váradi

// This file is part of XPLRA, a remote-access plugin for X-Plane

// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:

// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.

// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

#ifndef XPLRA_SETMULTIDATAREFREQUEST_H
#define XPLRA_SETMULTIDATAREFREQUEST_H
//------------------------------------------------------------------------------

#include "MultiTaskRequest.h"
#include "SetDataRefTask.h"

//------------------------------------------------------------------------------

namespace xplra {

//------------------------------------------------------------------------------

/**
 * A request containing several dataref update tasks.
 */
class SetMultiDataRefRequest : public MultiTaskRequestTemplate<SetDataRefTask>
{
public:
    /**
     * Construct the request by reading the task specifications from
     * the given stream.
     */
    SetMultiDataRefRequest(uint8_t& result, xplcommon::DataStream& stream);

    /**
     * Read the values of all tasks.
     */
    void readValues(xplcommon::DataStream& stream);

    /**
     * Write the result of an execution.
     *
     * If there is at least one invalid dataref, the result will be
     * RESULT_UNKNOWN_DATAREF followed by a 32-bit unsigned value with
     * the index of the first unknown dataref.
     *
     * Otherwise the result is RESULT_OK.
     */
    void writeResult(xplcommon::DataStream& stream) const;
};

//------------------------------------------------------------------------------

} /* namespace xplra */

//------------------------------------------------------------------------------
#endif // XPLRA_SETMULTIDATAREFREQUEST_H

// Local Variables:
// mode: C++
// c-basic-offset: 4
// indent-tabs-mode: nil
// End:
